@@ -5,16 +5,11 @@ use base qw(Business::ISBN);
 use Business::ISBN qw(:all);
 use Data::Dumper;
 
-use vars qw(
-	$VERSION
-	$debug
-	);
-
 use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '3.003';
+our $VERSION   = '3.005';
 
 sub _max_length { 13 }
 
@@ -71,7 +66,6 @@ sub _checksum {
 
 	return unless defined $data;
 
-	my @digits = split //, $data;
 	my $sum    = 0;
 
 	foreach my $index ( 0, 2, 4, 6, 8, 10 )
@@ -118,7 +112,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2001-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2001-2017, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This module is licensed under the Artistic License 2.0. See the LICENSE
 file in the distribution, or https://opensource.org/licenses/Artistic-2.0
